@@ -37,7 +37,11 @@ def get_svn_base_directory(project:dict, working_file_path):
         get svn repository acl directory
     '''
     root = os.path.join(project['file_tree']['working']['mountpoint'], project['file_tree']['working']['root'],project['name'].replace(' ', '_'),'')
-    base_svn_directory = os.path.join(f"{project['name']}:",working_file_path.split(root,1)[1])
+    print('ddddddddddddddddddddddddddddddddddddddddddddddddffffffffffffffffffff')
+    print(root)
+    print(working_file_path)
+    print(working_file_path.split(root,1))
+    base_svn_directory = os.path.join(f"{project['name']}:",working_file_path.split(root.lower(),1)[1])
     return base_svn_directory.lower()
 
 def get_base_file_directory():
