@@ -1095,13 +1095,13 @@ def assign_task(task_id, person_id):
     """
     Assign given person to given task. Emit a *task:assign* event.
     """
-    #TODO assign task
     task = get_task_raw(task_id)
     project_id = str(task.project_id)
     person = persons_service.get_person_raw(person_id)
 
     task.assignees.append(person)
-    genesis_service.grant_file_access(task, person, project_id)
+    #TODO assign task
+    # genesis_service.grant_file_access(task, person, project_id)
     task.save()
     task_dict = task.serialize()
     events.emit(
